==> u-boot-2011.12.tar.bz2: u-boot-2011.12/inc/x_inc/u_drm_prov.h <==
/* SPDX-License-Identifier: LGPL-2.1-only OR BSD-3-Clause */
/******************************************************************************
 *
 * This file is provided under a dual license.  When you use or
 * distribute this software, you may choose to be licensed under
 * version 2.1 of the GNU Lesser General Public License
 * ("LGPLv2.1 License") or BSD License.
 *
 * LGPLv2.1 License
 *
 * Copyright(C) 2019 MediaTek Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of version 2.1 of the GNU Lesser General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html for more
 * details.
 *
 * BSD LICENSE
 *
 * Copyright(C) 2019 MediaTek Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *****************************************************************************/

/*----------------------------------------------------------------------------*/
/*! @file u_drm_prov.h
 *  $RCSfile: $
 *  $Revision: #1 $
 *  $Date: 2015/06/02 $
 *  $Author: cong.wang $
 *
 *  @par Description:
 *         This header file contains drm provision specific
 *         definitions, which are exported.
 */
/*----------------------------------------------------------------------------*/

#ifndef _U_DRM_PROV_H_
#define _U_DRM_PROV_H_

/*------------------------------------------------------------------*/
/*! @enum DRM_PROV_T
 *  @brief DRM provision types
 */
/*------------------------------------------------------------------*/
typedef enum
{
    DRM_PLAYREADY_PROV,
    DRM_WIDEVINE_PROV,
    DRM_MARLIN_IPTV_ES_PROV,
    DRM_EMMC_PROV,
    DRM_PLAYREADY25_PROV,
    DRM_PLAYREADY30_PROV,
    DRM_ATTESTATION_PROV,
    DRM_DTCPIP_PROV,
    DRM_DTCPIP_CLEAN_KEY,
    DRM_CHINADRM_PROV,
    DRM_NFMGKID_PROV,
    DRM_PLAYREADY40_PROV,
    DRM_WV_GROUPCERT_PROV,
    DRM_KPM_PROV,
    DRM_CHINADRM_SM2_PROV,
    DRM_WV_GROUPCERT_PROV_MANUAL
} DRM_PROV_T;


typedef enum
{
    DRM_SECURITY_OK                   = 0,
	DRM_SECURITY_INVALID_PARAMETER = -101,
	DRM_SECURITY_MALLOC_FAIL      = -102,
	DRM_SECURITY_DECRYYPT_FAIL  =  -103,
	DRM_SECURITY_DECRYYPT_FAIL_PR25  =  -104,
	DRM_SECURITY_DECRYYPT_FAIL_PR30  =  -105,
    DRM_SECURITY_SIZE_ERR = -106,
    DRM_SECURITY_ENCRYPT_FAIL = -107,
	DRM_SECURITY_ENCRYPT_FAIL_PR25 = -108,
	DRM_SECURITY_ENCRYPT_FAIL_PR30 = -109,
	DRM_SECURITY_CHECK_SIZE_FAIL = -110,
	DRM_SECURITY_ENCEYPT_FILE_NOT_MATCH = -111
} DRM_SECURITY_RESULT_E;


#endif /*_U_DRM_PROV_H_*/

==> u-boot-2011.12-2011.12.tar.bz2: u-boot-2011.12-2011.12/inc/x_inc/u_drm_prov.h <==
/* SPDX-License-Identifier: LGPL-2.1-only OR BSD-3-Clause */
/******************************************************************************
 *
 * This file is provided under a dual license.  When you use or
 * distribute this software, you may choose to be licensed under
 * version 2.1 of the GNU Lesser General Public License
 * ("LGPLv2.1 License") or BSD License.
 *
 * LGPLv2.1 License
 *
 * Copyright(C) 2019 MediaTek Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of version 2.1 of the GNU Lesser General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html for more
 * details.
 *
 * BSD LICENSE
 *
 * Copyright(C) 2019 MediaTek Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *****************************************************************************/

/*----------------------------------------------------------------------------*/
/*! @file u_drm_prov.h
 *  $RCSfile: $
 *  $Revision: #1 $
 *  $Date: 2015/06/02 $
 *  $Author: cong.wang $
 *
 *  @par Description:
 *         This header file contains drm provision specific
 *         definitions, which are exported.
 */
/*----------------------------------------------------------------------------*/

#ifndef _U_DRM_PROV_H_
#define _U_DRM_PROV_H_

/*------------------------------------------------------------------*/
/*! @enum DRM_PROV_T
 *  @brief DRM provision types
 */
/*------------------------------------------------------------------*/
typedef enum
{
    DRM_PLAYREADY_PROV,
    DRM_WIDEVINE_PROV,
    DRM_MARLIN_IPTV_ES_PROV,
    DRM_EMMC_PROV,
    DRM_PLAYREADY25_PROV,
    DRM_PLAYREADY30_PROV,
    DRM_ATTESTATION_PROV,
    DRM_DTCPIP_PROV,
    DRM_DTCPIP_CLEAN_KEY,
    DRM_CHINADRM_PROV,
    DRM_NFMGKID_PROV,
    DRM_PLAYREADY40_PROV,
	DRM_WV_GROUPCERT_RPOV
} DRM_PROV_T;


typedef enum
{
    DRM_SECURITY_OK                   = 0,
	DRM_SECURITY_INVALID_PARAMETER = -101,
	DRM_SECURITY_MALLOC_FAIL      = -102,
	DRM_SECURITY_DECRYYPT_FAIL  =  -103,
	DRM_SECURITY_DECRYYPT_FAIL_PR25  =  -104,
	DRM_SECURITY_DECRYYPT_FAIL_PR30  =  -105,
    DRM_SECURITY_SIZE_ERR = -106,
    DRM_SECURITY_ENCRYPT_FAIL = -107,
	DRM_SECURITY_ENCRYPT_FAIL_PR25 = -108,
	DRM_SECURITY_ENCRYPT_FAIL_PR30 = -109,
	DRM_SECURITY_CHECK_SIZE_FAIL = -110,
	DRM_SECURITY_ENCEYPT_FILE_NOT_MATCH = -111
} DRM_SECURITY_RESULT_E;


#endif /*_U_DRM_PROV_H_*/
